==> haskell-resourcet-1.1.8.1-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-resourcet.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: resourcet
version: 1.1.8.1
id: resourcet-1.1.8.1-Fz8VsTwAt9A4JeouKpXV1P
key: resourcet-1.1.8.1-Fz8VsTwAt9A4JeouKpXV1P
license: BSD3
maintainer: michael@snoyman.com
homepage: http://github.com/snoyberg/conduit
synopsis: Deterministic allocation and freeing of scarce resources.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/resourcet>.
category: Data, Conduit
author: Michael Snoyman
exposed: True
exposed-modules:
    Control.Monad.Trans.Resource Control.Monad.Trans.Resource.Internal
    Data.Acquire Data.Acquire.Internal
abi: bf9ed2c0e8f770ed49c2fe4c24fd16b6
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/resourcet-1.1.8.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/resourcet-1.1.8.1
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/resourcet-1.1.8.1
hs-libraries: HSresourcet-1.1.8.1-Fz8VsTwAt9A4JeouKpXV1P
depends:
    base-4.9.0.0 containers-0.5.7.1
    exceptions-0.8.3-5cAKIsqc1DD7jaNW3zLxAN
    lifted-base-0.2.3.8-49pRtI70Gt75UpVUvp7oxA
    mmorph-1.0.9-DmSwQqk5nLj7roLAcydGz
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM transformers-0.5.2.0
    transformers-base-0.4.4-LWS58Nywv1PJoy1IFDbvS4
    transformers-compat-0.5.1.4-81lZyuOJOvsD0zyCv2TKld
haddock-interfaces: /usr/share/doc/haskell-resourcet/html/resourcet.haddock
haddock-html: /usr/share/doc/haskell-resourcet/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-resourcet-1.1.8-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-resourcet.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: resourcet
version: 1.1.8
id: resourcet-1.1.8-809VyiwX9IhH0X7rbGoy6q
key: resourcet-1.1.8-809VyiwX9IhH0X7rbGoy6q
license: BSD3
maintainer: michael@snoyman.com
homepage: http://github.com/snoyberg/conduit
synopsis: Deterministic allocation and freeing of scarce resources.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/resourcet>.
category: Data, Conduit
author: Michael Snoyman
exposed: True
exposed-modules:
    Control.Monad.Trans.Resource Control.Monad.Trans.Resource.Internal
    Data.Acquire Data.Acquire.Internal
abi: 60caf95265636535eea7d381bde9ab49
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/resourcet-1.1.8
library-dirs: /usr/lib/ghc-8.0.1/site-local/resourcet-1.1.8
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/resourcet-1.1.8
hs-libraries: HSresourcet-1.1.8-809VyiwX9IhH0X7rbGoy6q
depends:
    base-4.9.0.0 containers-0.5.7.1
    exceptions-0.8.3-5cAKIsqc1DD7jaNW3zLxAN
    lifted-base-0.2.3.8-49pRtI70Gt75UpVUvp7oxA
    mmorph-1.0.9-DmSwQqk5nLj7roLAcydGz
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM transformers-0.5.2.0
    transformers-base-0.4.4-LWS58Nywv1PJoy1IFDbvS4
    transformers-compat-0.5.1.4-81lZyuOJOvsD0zyCv2TKld
haddock-interfaces: /usr/share/doc/haskell-resourcet/html/resourcet.haddock
haddock-html: /usr/share/doc/haskell-resourcet/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
